==> haskell-fdo-notify-0.3.1-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-7sKJUYbDWKh6oSXZfX15t0
key: fdo-notify-0.3.1-7sKJUYbDWKh6oSXZfX15t0
license: BSD3
maintainer: max.rabkin@gmail.com
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
author: Max Rabkin
exposed: True
indefinite: False
exposed-modules:
    DBus.Notify
abi: ad78343badc0afc76d082b7cbbe990d9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-7sKJUYbDWKh6oSXZfX15t0
depends:
    base-4.10.1.0 containers-0.5.10.2
    dbus-0.10.15-ISpqX6M3WzLA5QxCFmo9fg
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             dbus-0.10.15-ISpqX6M3WzLA5QxCFmo9fg=cf2e712f90ad4cec5eec3ec861a4b88d
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-39-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-ADL8r0GqH1E38D7FLN3nrQ
key: fdo-notify-0.3.1-ADL8r0GqH1E38D7FLN3nrQ
license: BSD3
maintainer: max.rabkin@gmail.com
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
author: Max Rabkin
exposed: True
indefinite: False
exposed-modules:
    DBus.Notify
abi: 48689e75260f804d3cb1be237f06b0b2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-ADL8r0GqH1E38D7FLN3nrQ
depends:
    base-4.10.1.0 containers-0.5.10.2
    dbus-0.10.15-2vHnGf7plPk5Iw231AzDQd
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             dbus-0.10.15-2vHnGf7plPk5Iw231AzDQd=013cf1c4e9a69fe7f7cc1d8d42962056
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
